#' @importFrom utils bibentry
bibentries = c(
    li_2018 = bibentry("article",
      key     = "li_2018",
      author  = "Lisha Li and Kevin Jamieson and Giulia DeSalvo and Afshin Rostamizadeh and Ameet Talwalkar",
      title   = "Hyperband: A Novel Bandit-Based Approach to Hyperparameter Optimization",
      journal = "Journal of Machine Learning Research",
      year    = "2018",
      volume  = "18",
      number  = "185",
      pages   = "1-52",
      url     = "https://jmlr.org/papers/v18/16-558.html"
  ),

    jamieson_2016 = bibentry("InProceedings",
      key       =    "jamieson_2016",
      title     = 	 "Non-stochastic Best Arm Identification and Hyperparameter Optimization",
      author    = 	 "Kevin Jamieson and Ameet Talwalkar",
      booktitle =    "Proceedings of the 19th International Conference on Artificial Intelligence and Statistics",
      pages     = 	 "240-248",
      year      = 	 "2016",
      editor    = 	 "Arthur Gretton and Christian C. Robert",
      volume    = 	 "51",
      series    = 	 "Proceedings of Machine Learning Research",
      address   = 	 "Cadiz, Spain",
      publisher =    "PMLR",
      url       = "http://proceedings.mlr.press/v51/jamieson16.html")
)
